///
/// @file	serialTX.h
/// @brief	Library header
///
/// @details	Single Serial TX Library
/// @n	
/// @n @b	Project VAW_main
/// @n @a	Developed with [embedXcode](http://embedXcode.weebly.com)
/// 
/// @author	Rei VILO
/// @author	embedXcode.weebly.com
/// @date	mars 18, 2013 14:44
/// @version	106
/// 
/// @copyright	© Rei VILO, 2013
/// @copyright	CC = BY NC SA
///
/// @see	ReadMe.txt for references
/// Contributions
/// *	roadrunner84, Mar 21, 2013
/// @n	http://forum.43oh.com/topic/3551-very-basic-software-serial-tx-only-library/?p=31669
///


// Core library - IDE-based
#if defined(ENERGIA) // LaunchPad, FraunchPad and StellarPad specific
#include "Energia.h"
#endif // end IDE

#ifndef serialTX_LocalLibrary_h
#define serialTX_LocalLibrary_h

#include "Stream.h"

///
/// @brief	Basic Serial TX Library
///
class SerialTX : public Stream
{
public:
    ///
    /// @brief	Define pin for TX
    /// @param	pin number of pin
    ///
    SerialTX(uint8_t pin);

    ///
    /// @brief	Begin
    /// @note	no speed required, default=9600
    ///
    void begin();

    /// @name	Virtual functions from stream
    ///
    /// @{

    int available() { return 0; }
    int read() { return -1; }
    int peek() { return -1; }
    void flush() { ; }

    /// @}
    
    ///
    /// @brief	Write routine
    /// @param	ui8 char or uint8_t
    /// @return	number of written bytes, =1
    /// @note	virtual function from print
    ///
    size_t write(uint8_t ui8);

private:
    uint8_t _pin;
};


#endif
